==> pyglotaran_extras-0.6.0.tar.gz: pyglotaran_extras-0.6.0/README.md <==
# pyglotaran-extras

[![PyPI version](https://badge.fury.io/py/pyglotaran-extras.svg)](https://badge.fury.io/py/pyglotaran-extras)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/pyglotaran-extras.svg)](https://anaconda.org/conda-forge/pyglotaran-extras)
[![Tests](https://github.com/glotaran/pyglotaran-extras/actions/workflows/test.yml/badge.svg)](https://github.com/glotaran/pyglotaran-extras/actions/workflows/test.yml)
[![Documentation Status](https://readthedocs.org/projects/pyglotaran-extras/badge/?version=latest)](https://pyglotaran-extras.readthedocs.io/en/latest/?badge=latest)
[![Binder](https://static.mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/glotaran/pyglotaran-extras.git/main?urlpath=lab%2Ftree%2Fdocs%2Fsource%2Fnotebooks)

[![codecov](https://codecov.io/gh/glotaran/pyglotaran-extras/branch/main/graph/badge.svg?token=I6F412Y390)](https://codecov.io/gh/glotaran/pyglotaran-extras)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/glotaran/pyglotaran-extras.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/glotaran/pyglotaran-extras/context:python)
[![Code style Python: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Discord](https://img.shields.io/discord/883443835135475753.svg?label=&logo=discord&logoColor=ffffff&color=7389D8&labelColor=6A7EC2)](https://discord.gg/KfnEYRSTJx)

Supplementary package for pyglotaran with (example) plotting code for use with the pyglotaran package.
Can be installed as a python package or from sources.

## Installation

Prerequisites:

- Python 3.8 or 3.9
- Python package `pyglotaran` v0.3.0 (or later)

### Stable Release

To install pyglotaran-extras from [PyPI](https://pypi.org/), run this command in your terminal:

```console
pip install pyglotaran-extras
```

If you want to install it via conda, you can run the following command:

```console
conda install pyglotaran-extras
```

### From Source

To install pyglotaran-extras from sources, either clone this repository or download the latest release, then run this command in your terminal:

```console
git clone https://github.com/glotaran/pyglotaran-extras.git
cd pyglotaran-extras
pip install -e .
```

or directly

```console
pip install git+https://github.com/glotaran/pyglotaran-extras.git
```

==> pyglotaran_extras-0.7.0.tar.gz: pyglotaran_extras-0.7.0/README.md <==
# pyglotaran-extras

[![PyPI version](https://badge.fury.io/py/pyglotaran-extras.svg)](https://badge.fury.io/py/pyglotaran-extras)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/pyglotaran-extras.svg)](https://anaconda.org/conda-forge/pyglotaran-extras)
[![Tests](https://github.com/glotaran/pyglotaran-extras/actions/workflows/test.yml/badge.svg)](https://github.com/glotaran/pyglotaran-extras/actions/workflows/test.yml)
[![Documentation Status](https://readthedocs.org/projects/pyglotaran-extras/badge/?version=latest)](https://pyglotaran-extras.readthedocs.io/en/latest/?badge=latest)
[![Binder](https://static.mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/glotaran/pyglotaran-extras.git/main?urlpath=lab%2Ftree%2Fdocs%2Fsource%2Fnotebooks)

[![codecov](https://codecov.io/gh/glotaran/pyglotaran-extras/branch/main/graph/badge.svg?token=I6F412Y390)](https://codecov.io/gh/glotaran/pyglotaran-extras)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/glotaran/pyglotaran-extras.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/glotaran/pyglotaran-extras/context:python)
[![Code style Python: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Discord](https://img.shields.io/discord/883443835135475753.svg?label=&logo=discord&logoColor=ffffff&color=7389D8&labelColor=6A7EC2)](https://discord.gg/KfnEYRSTJx)

Supplementary package for pyglotaran with (example) plotting code for use with the pyglotaran package.
Can be installed as a python package or from sources.

## Installation

Prerequisites:

- Python 3.8 or 3.9
- Python package `pyglotaran` v0.3.0 (or later)

### Stable Release

To install pyglotaran-extras from [PyPI](https://pypi.org/), run this command in your terminal:

```console
pip install pyglotaran-extras
```

If you want to install it via conda, you can run the following command:

```console
conda install -c conda-forge pyglotaran-extras
```

### From Source

To install pyglotaran-extras from sources, either clone this repository or download the latest release, then run this command in your terminal:

```console
git clone https://github.com/glotaran/pyglotaran-extras.git
cd pyglotaran-extras
pip install -e .
```

or directly

```console
pip install git+https://github.com/glotaran/pyglotaran-extras.git
```
